@@ -947,7 +947,7 @@
   HALF%PI FOURTH%PI %P%I MAX-BFLOAT-%E MAX-BFLOAT-%PI *DECFP *M FPPREC
   BIGFLOAT%PI BIGFLOAT%E BFMHALF BFHALF BIGFLOATONE BIGFLOATZERO
   $FPPREC $FPPRINTPREC $BFTRUNC $BFTORAT $FLOAT2BF *AFTERFLAG
-  MACHINE-MANTISSA-PRECISION DERIVSIMP ERRORSW DOSIMP $MAXNEGEX
+  DERIVSIMP ERRORSW DOSIMP $MAXNEGEX
   $MAXPOSEX $EXPON $EXPOP $MX0SIMP $DOMXTIMES $DOMXPLUS $DOMXEXPT
   $DOSCMXPLUS $NUMER_PBRANCH $SUMEXPAND $SIMP $NUMER $NEGDISTRIB
   $FLOAT $MACROEXPANSION $USE_FAST_ARRAYS $SETCHECK MUNBINDP
