@@ -241,8 +241,10 @@
 	   ((lessp q 1) ans)
 	   (setq q (sub1 q) m (*dif m n) ans (times m ans))))
  
+#+nil
 (declare-top (flonum a r))
 
+#+nil
 (defun gammafloat (a) 
        (cond ((= a 1.0) 1.0)
 	     ((= a 0.0) (merror "GAMMA(0.0) has been generated."))	
@@ -261,6 +263,7 @@
 ;	     (dbg:floating-exponent-overflow 
 ;	       (merror "GAMMA(~A) - arithmetic overflow" a))))))
 
+#+nil
 (defun do-gammafloat (a)
   (do ((r 1.0 (*$ z r))
        (s (minusp a)) (z (abs a)))
@@ -270,6 +273,76 @@
 	     (t r))) 
     (setq z (1-$ z))))
 
+;; This implementation is based on Lanczos convergent formula for the
+;; gamma function for Re(z) > 0.  We can use the reflection formula
+;;
+;;    -z*Gamma(z)*Gamma(-z) = pi/sin(pi*z)
+;;
+;; to handle the case of Re(z) <= 0.
+;;
+;; See http://winnie.fit.edu/~gabdo/gamma.m for some matlab code to
+;; compute this and http://winnie.fit.edu/~gabdo/gamma.txt for a nice
+;; discussion of Lanczos method and an improvement of Lanczos method.
+;;
+;;
+;; The document says this should give about 15 digits of accuracy for
+;; double-precision IEEE floats.  The document also indicates how to
+;; compute a new set of coefficients if you need more range or
+;; accuracy.
+
+(defun gamma-lanczos (z)
+  (declare (type (complex double-float) z)
+	   (optimize (safety 3)))
+  (let ((g 607/128)
+	(c (make-array 15 :element-type 'double-float
+		       :initial-contents
+		       '(0.99999999999999709182d0
+			 57.156235665862923517d0
+			 -59.597960355475491248d0
+			 14.136097974741747174d0
+			 -0.49191381609762019978d0
+			 .33994649984811888699d-4
+			 .46523628927048575665d-4
+			 -.98374475304879564677d-4
+			 .15808870322491248884d-3
+			 -.21026444172410488319d-3
+			 .21743961811521264320d-3
+			 -.16431810653676389022d-3
+			 .84418223983852743293d-4
+			 -.26190838401581408670d-4
+			 .36899182659531622704d-5))))
+    (declare (type (rational 607/128 607/128) g)
+	     (type (simple-array double-float (15)) c))
+    (if (minusp (realpart z))
+	;; Use the reflection formula
+	;; -z*Gamma(z)*Gamma(-z) = pi/sin(pi*z)
+	;; or
+	;; Gamma(z) = pi/z/sin(pi*z)/Gamma(-z)
+	;;
+	;; If z is a negative integer, Gamma(z) is infinity.  Should
+	;; we test for this?  Throw an error?  What
+	(/ (float pi 1d0)
+	   (* (- z) (sin (* (float pi 1d0)
+			    z))
+	      (gamma-lanczos (- z))))
+	(let* ((z (- z 1))
+	       (zh (+ z 1/2))
+	       (zgh (+ zh 607/128))
+	       (zp (expt zgh (/ zh 2)))
+	       (ss 
+		 (do ((sum 0d0)
+		      (pp (1- (length c)) (1- pp)))
+		     ((< pp 1)
+		      sum)
+		   (incf sum (/ (aref c pp) (+ z pp))))
+		 ))
+	  (* (sqrt (float (* 2 pi) 1d0))
+	     (+ ss (aref c 0))
+	     (* zp (exp (- zgh)) zp))))))
+
+(defun gammafloat (a)
+  (realpart (gamma-lanczos (complex a 0d0))))
+
 (declare-top (notype a r))
 
 (declare-top (SPLITFILE ERF) (SPECIAL $NUMER $TRIGSIGN))
@@ -285,6 +358,7 @@
        ((and $trigsign (mminusp* y)) (neg (list '(%erf simp) (neg y))))
        (t (eqtest (list '(%erf) y) x))))
 
+#+nil
 (defmfun erf (y)
        (cond ((> (abs y) 4.0) (cond ((> y 0.0) 1.0) (t -1.0)))
 	     (t ((lambda (t1 xf)
@@ -308,7 +382,13 @@
 			  t1))))
 		   (cond ((> y 0.0) t1) (t (minus t1))))
 		  0.0
-		  (abs y))))) 
+		  (abs y)))))
+
+(defmfun erf (y)
+  (slatec:derf (float y 1d0)))
+(defmfun erfc (y)
+  (slatec:derfc (float y 1d0)))
+
 
 (declare-top (SPLITFILE EMATRIX))
 
