@@ -222,13 +222,13 @@
 		   (merror "Variable of integration not a variable: ~M"
 			   VAR))
 		  (($SUBVARP VAR)  (SETQ VAR (STRIPDOLLAR (CAAR VAR)))
-				   (SETQ EXP (SUBST VAR orig-VAR EXP))))
+				   (SETQ EXP ($SUBSTITUTE VAR orig-VAR EXP))))
 	    (COND ((NOT (ATOM VAR))
 		   (merror "Improper variable of integration: ~M" VAR))
 		  ((OR (AMONG VAR UL)
 		       (AMONG VAR LL)) 
 		   (SETQ VAR (STRIPDOLLAR VAR))
-		   (SETQ EXP (SUBST VAR orig-VAR EXP))))
+		   (SETQ EXP ($SUBSTITUTE VAR orig-VAR EXP))))
 	    (cond ((not (equal ($ratsimp ($imagpart ll)) 0))
 		   (merror "Defint: Lower limit of integration must be real."))
 		  ((not (equal ($ratsimp ($imagpart ul)) 0))
@@ -1491,7 +1491,9 @@
 ;;; B<=%PI2
 
 (DEFUN PERIOD (P E VAR)
-       (ALIKE1 E (NO-ERR-SUB (m+ P VAR) E))) 
+  (and (ALIKE1 (no-err-sub var E) (setq e (NO-ERR-SUB (m+ P VAR) E)))
+       ;; means there was no error
+       (not (eq e t))))
 
 (DEFUN INFR (A)
   (let ((var '$%i)
