@@ -33,7 +33,12 @@
 ;;at all, that caught no errors but at least
 ;;returned a list in the normal case would be 
 
+#+(or cmu clisp)
+(defmacro errset (&rest l)
+   `(handler-case (list ,(car l))
+     (error (e) (when errset (error e)))))
 
-#-(or excl lucid)
+#-(or excl clisp cmu lucid)
 (defmacro errset (&rest l) `(list ,(car l)))
 
+
