@@ -38,7 +38,12 @@
 
 (DEFMACRO SIMP-LIST (L) `(MAPCAR #'(LAMBDA (X) (SIMP X)) ,L))
 
-(DEFMACRO MABS (X) `(SIMP `((MABS) ,,X)))
+; The macro MABS has been renamed to HYP-MABS in order to
+; avoid conflict with the Maxima symbol MABS. The other
+; M* macros defined here should probably be similarly renamed
+; for consistency. jfa 03/27/2002
+
+(DEFMACRO HYP-MABS (X) `(SIMP `((MABS) ,,X)))
 
 (DEFMACRO MSQRT (X) `(M^T ,X 1//2))
 
@@ -118,7 +123,7 @@
 (DEFUN SIMPG
        (L1 L2)
        (PROG(IL)
-	    (COND ((NULL (SETQ IL (INTERSECTION L1 L2)))
+	    (COND ((NULL (SETQ IL (zl-INTERSECTION L1 L2)))
 		   (RETURN (SIMPG-EXEC L1 L2))))
 	    (RETURN (SIMPG-EXEC (DEL IL L1)(DEL IL L2)))))   
 
@@ -463,14 +468,14 @@
 	     (T (hyp-NEGP-IN-L (CDR L)))))
 
 
-(DEFUN INTERSECTION
+(DEFUN zl-INTERSECTION
        (L1 L2)
        (cond ((null l1) nil)
 	     ((zl-member (car l1) l2)
 	      (cons (car l1)
-		    (intersection (cdr l1)
+		    (zl-intersection (cdr l1)
 				  (zl-delete (car l1) l2 1))))
-	     (t (intersection (cdr l1) l2))))
+	     (t (zl-intersection (cdr l1) l2))))
 
 (DEFUN 2INP
        (L)
@@ -559,15 +564,15 @@
 		   l ($denom kl))
 	     (cond ((equal (* 2 l) n)
 		    (cond ((maxima-integerp (// (- k m) n))
-			   (return (hyp-algv k l m n a b))))))
+			   (return (hyp-algv k l m n a b c))))))
 	     (cond ((maxima-integerp (// k (* 2 l)))
 		    (cond ((maxima-integerp (// m n))
-			   (return (hyp-algv k l m n a b)))
+			   (return (hyp-algv k l m n a b c)))
 			  (t (return nil))))
 		   ((maxima-integerp (// m n))
 			   (return nil))
 		   ((maxima-integerp (/ (- (* k n) (* 2 l m)) (* 2 l n)))
-		    (return (hyp-algv k l m n a b))))
+		    (return (hyp-algv k l m n a b c))))
 	     (return nil)))
 
 (defun getxy
@@ -1225,7 +1230,7 @@
 				    (SETQ B (M-T A B)))
 			       (M^T (M-T X Z) B))))
 		    (T ())))
-	     ((=1//2 (MABS (M-T B A)))
+	     ((=1//2 (HYP-MABS (M-T B A)))
 	      (COND ((EQUAL (CHECKSIGNTM VAR) '$POSITIVE)
 		     (M*T 1//2
 			  (M+T (M^T (M1+T (SETQ Z (MSQRT VAR)))
