@@ -60,15 +60,42 @@
 (defun used-area ( &optional (area working-storage-area ))
   (multiple-value-bind (nil used)(si:room-get-area-length-used area)
     used))
- 
-(DEFUN CONTINUE (&OPTIONAL (*standard-input* *standard-input*)
+
+#+cmu
+(defun used-area (&optional unused)
+  (declare (ignore unused))
+  (ext:get-bytes-consed))
+
+#+clisp
+(defun used-area (&optional unused)
+  (declare (ignore unused))
+  (multiple-value-bind (real1 real2 run1 run2 gc1 gc2 space1 space2 gccount)
+      (sys::%%time)
+    (declare (ignore real1 real2 run1 run2 gc1 gc2 gccount))
+    (dpb space1 (byte 24 24) space2)))
+
+#-(or lispm cmu clisp)
+(defun used-area (&optional unused)
+  (declare (ignore unused))
+  0)
+
+(DEFUN CONTINUE (&OPTIONAL (input-stream *standard-input*)
 			   BATCH-OR-DEMO-FLAG)
  (if (eql BATCH-OR-DEMO-FLAG :demo)
      (format t "~% At the _ prompt, type ';' followed by enter to get next demo"))
  (catch 'abort-demo
-  (DO ((R) (time-before) (time-after) (time-used) (EOF (LIST NIL))
-       (etime-before) (etime-after) #+lispm (area-before)#+lispm (area-after)
-       (etime-used) (c-tag) (d-tag))
+  (DO ((R)
+       (time-before)
+       (time-after)
+       (time-used)
+       (EOF (LIST NIL))
+       (etime-before)
+       (etime-after)
+       (area-before)
+       (area-after)
+       (etime-used)
+       (c-tag)
+       (d-tag))
       (NIL)
     (when (not (checklabel $inchar))
 	  (setq $linenum (f1+ $linenum)))
@@ -78,9 +105,24 @@
 	  (eof-count 0))
     (tagbody
      top
-     (SETQ R      (dbm-read *standard-input* nil eof))
+     (SETQ R      (dbm-read input-stream nil eof))
+     ; This is something of a hack. If we are running in a server mode
+     ; (which we determine by checking *socket-connection*) and we get
+     ; an eof on an input-stream that is not *standard-input*, switch
+     ; the input stream to *standard-input*.
+     ; There should probably be a better scheme for server mode.
+     ; jfa 10/09/2002.
+     (if (and
+	  (eq r eof)
+	   (not (eq input-stream *standard-input*))
+	   (boundp '*socket-connection*))
+	 (progn
+	       (setq input-stream *standard-input*)
+	       (setq *mread-prompt* nil)
+	       (setq r (dbm-read input-stream nil eof))))
+
      (cond ((and (eq r eof) (boundp '*socket-connection*)
-		 (eq *standard-input* *socket-connection*))
+		 (eq input-stream *socket-connection*))
 	    (cond ((>=  (setq eof-count (+ 1 eof-count)) 10)
 		   (print "exiting on eof")
 		   ($quit))
@@ -106,12 +148,12 @@
 	   (displa `((mlable) ,c-tag , $__))))
     (setq time-before (get-internal-run-time)
 	  etime-before (get-internal-real-time))
-    #+lispm (setq area-before (used-area))
+    (setq area-before (used-area))
     (SETQ $% (TOPLEVEL-MACSYMA-EVAL $__))
     (setq etime-after (get-internal-real-time)
 	  time-after (get-internal-run-time))
-    #+lispm (setq area-after (used-area))
-	(setq time-used (quotient (float (difference time-after time-before))
+    (setq area-after (used-area))
+    (setq time-used (quotient (float (difference time-after time-before))
 			      internal-time-units-per-second)
 	  etime-used (quotient (float (difference etime-after etime-before))
 			       internal-time-units-per-second))
@@ -126,6 +168,17 @@
 	  (format t "~&Evaluation took ~$ seconds (~$ elapsed)"
        		    time-used etime-used )
 	  #+lispm (format t "using ~A words." (f-  area-after area-before))
+	  #+(or cmu clisp)
+	  (let ((total-bytes (- area-after area-before)))
+	    (cond ((> total-bytes 1024)
+		   (format t " using ~,3F KB." (/ total-bytes 1024.0))
+		   )
+		  ((> total-bytes (* 1024 1024))
+		   (format t " using ~,3F MB." (/ total-bytes (* 1024.0 1024.0)))
+		   )
+		  (t
+		   (format t " using ~:D bytes." total-bytes))))
+
       )
     (UNLESS $NOLABELS
 		     (PUTPROP d-tag
@@ -143,7 +196,7 @@
 	     ;;those are common lisp characters you'r reading here
 	    (case
 	     (setq char (read-char *terminal-io*))
-	     ((#\page) (unless (cursorpos 'c *standard-input*) (terpri *standard-output*))
+	     ((#\page) (unless (cursorpos 'c input-stream) (terpri *standard-output*))
 	      (princ "_" *standard-output*))
 	     ((#\?) (mtell "  Pausing.  Type a ';' and Enter to continue demo.~%_"))
 	     ((#\space #\; #\n #\e #\x #\t))
@@ -154,11 +207,11 @@
     ;; This is sort of a kludge -- eat newlines and blanks so that they don't echo
     (AND BATCH-OR-DEMO-FLAG
 	 #+lispm
-	 (send *standard-input* :operation-handled-p :read-char-no-echo)
+	 (send input-stream :operation-handled-p :read-char-no-echo)
 	 #+lispm
-	 (send *standard-input* :operation-handled-p :unread-char-no-echo)
+	 (send input-stream :operation-handled-p :unread-char-no-echo)
 	 (do ((char)) (())
-	   (setq char (read-char *standard-input* nil #+cl nil)) 
+	   (setq char (read-char input-stream nil #+cl nil)) 
 
 ;;;; INSERTED BY MASAMI 
            (when (null char) 
@@ -166,7 +219,7 @@
 ;;;; END INSERT 
 
 	   (unless (zl-MEMBER char '(#\space #\newline #\return #\tab))
-	       (unread-char char *standard-input*)  
+	       (unread-char char input-stream)  
 	     (return nil))))))) 
 
 
@@ -286,12 +339,48 @@
 (DEFUN $DEMO (&REST ARG-LIST)
   (BATCH (FILENAME-FROM-ARG-LIST ARG-LIST) T))
 
+(defmfun $bug_report ()
+  (format t "~%The Maxima bug database is available at~%")
+  (format t "    http://sourceforge.net/tracker/?atid=104933&group_id=4933&func=browse~%")
+  (format t "Submit bug reports by following the 'Submit New' link on that page.~%")
+  (format t "Please include the following build information with your bug report:~%")
+  (format t "-------------------------------------------------------------~%")
+  ($build_info)
+  (format t "-------------------------------------------------------------~%")
+  (format t "The above information is also available from the Maxima function build_info().~%~%")
+  "")
+
+(defmfun $build_info ()
+  (format t "~%Maxima version: ~a~%" *autoconf-version*)
+  (format t "Maxima build date: ~a:~a ~a/~a/~a~%"
+	  (third user:*maxima-build-time*)
+	  (second user:*maxima-build-time*)
+	  (fifth user:*maxima-build-time*)
+	  (fourth user:*maxima-build-time*)
+	  (sixth user:*maxima-build-time*))
+  (format t "host type: ~a~%" *autoconf-host*)
+  (format t "lisp-implementation-type: ~a~%" (lisp-implementation-type))
+  (format t "lisp-implementation-version: ~a~%~%" (lisp-implementation-version))
+  "")
+
+(defvar *maxima-started* nil)
+
 #-lispm
-(defun macsyma-top-level ()
+(defun macsyma-top-level (&OPTIONAL (input-stream *standard-input*)
+				    batch-flag)
   (let ((*package* (find-package "MAXIMA")))
-    (apply 'format t
-	   "Maxima ~a.~a ~a (with enhancements by W. Schelter).~%Licensed under the GNU Public License (see file COPYING)~%"
-	   (get :maxima :version))
+    (if *maxima-started*
+	(format t "Maxima restarted.~%")
+      (progn
+	(format t "Maxima ~a http://maxima.sourceforge.net~%"
+		*autoconf-version*)
+	(format t "Distributed under the GNU Public License. See the file COPYING.~%")
+	(format t "Dedicated to the memory of William Schelter.~%")
+	(format t "This is a development version of Maxima. The function bug_report()~%")
+	(format t "provides bug reporting information.~%")
+	(setq *maxima-started* t)))
+    (if ($file_search "maxima-init.lisp") ($load "maxima-init.lisp"))
+    (if ($file_search "maxima-init.mac") ($batchload "maxima-init.mac"))
     
    (catch 'quit-to-lisp
      (in-package "MAXIMA")
@@ -299,7 +388,7 @@
 	 do
        (catch #+kcl si::*quit-tag* #+cmu 'continue #-(or kcl cmu) nil
 	      (catch 'macsyma-quit
-		(continue)(bye)))))))
+		(continue input-stream batch-flag)(bye)))))))
 
 #-lispm
 (progn 
@@ -311,9 +400,44 @@
   (throw 'macsyma-quit t))
 
 
-(defmfun $writefile (x) (dribble (subseq (string x) 1))) 
- 
-(defmfun $closefile () (dribble)) 
+(defmfun $writefile (x) (dribble (subseq (string x) 1)))
+(defvar $appendfile nil )
+(defmfun $appendfile (name)
+  (if (and (symbolp name)
+	   (member (getcharn name 1) '(#\& #\$)))
+      (setq name (subseq (symbol-name name) 1)))
+  (if $appendfile (merror "already in appendfile, use closefile first"))
+  (let ((stream  (open name :direction :output
+                                       :if-exists :append
+                                       :if-does-not-exist :create)))
+  (setq *appendfile-data* (list stream *terminal-io* name ))
+  
+  (setq $appendfile (make-two-way-stream
+		     (make-echo-stream *terminal-io* stream)
+		     (make-broadcast-stream *terminal-io* stream))
+	*terminal-io* $appendfile)
+  (multiple-value-bind (sec min hour day month year)
+		       (get-decoded-time)
+		       (format t
+			       "~&/* Starts dribbling to ~A (~d/~d/~d, ~d:~d:~d).*/"
+			       name year month day hour min sec))
+  '$done))
+  
+(defmfun $closefile ()
+  (cond ($appendfile
+	 
+	 (cond ((eq $appendfile *terminal-io*)
+                 (format t "~&/*Finished dribbling to ~A.*/"
+			 (nth 2 *appendfile-data*))
+		(setq *terminal-io* (nth 1 *appendfile-data*))
+		)
+	       (t  (warn "*TERMINAL-IO* was rebound while APPENDFILE is on.~%~
+                   You may miss some dribble output.")))
+	 (close (nth 0 *appendfile-data*))
+	 (setq *appendfile-data* nil $appendfile nil)
+	 
+	 )
+	(t (dribble))))
  
 
 (defmfun $ed (x) (ed (subseq (string x) 1))) 
@@ -352,5 +476,14 @@
 #+gcl
 (defun $system (&rest x) (system (apply '$sconcat x)))
 
+#+clisp
+(defun $system (&rest x) (ext:run-shell-command (apply '$sconcat x)))
 
+#+cmu
+(defun $system (&rest args)
+  (ext:run-program "/bin/sh" (list "-c" (apply '$sconcat args))))
 
+(defun $room (&optional (arg nil arg-p))
+  (if arg-p
+      (room arg)
+      (room)))
