@@ -791,8 +791,6 @@
 	      (setq next-result  (third next))
 	      (cond ((batch-equal-check next-result result)
 		     (format t "~%..Which was correct"))
-		    ((eq t next-result)
-		     (format t "~%..Which made the predicate true"))
 		    (t (format t "~%This differed from the expected result:")
 		       (push i all-differences)
 		       (displa next-result)
@@ -855,7 +853,7 @@
 (defun $file_search (name &optional paths)
   (if (and (symbolp name)
 	   (member (getcharn name 1) '(#\& #\$)))
-      (setq name ($sconcat name)))
+      (setq name (subseq (symbol-name name) 1)))
   (if (symbolp name)  (setf name (string name)))
   (if (probe-file name) (return-from $file_search name))
   (or paths (setq paths ($append $file_search_lisp  $file_search_maxima
